@@ -8,30 +8,41 @@ from mypy_boto3_s3 import S3Client, S3ServiceResource
 from mypy_boto3_secretsmanager import SecretsManagerClient
 from mypy_boto3_ses import SESClient
 from mypy_boto3_sqs import SQSClient
-
 from pydantic import BaseModel, EmailStr, validator
 
+
 #
 # GENERIC
 #
 
 
-class Config(BaseModel):
+class AuthConfig(BaseModel):
     cache_update_threshold: int
     cookie_max_age_days: int
     cookie_security: bool
     cors_allow_origin: str
-    honeycomb_secret_id: str  # honeycomb.io API key
+    honeycomb_secret_id: Optional[str]  # honeycomb.io API key
     jwt_name: str  # jwt-ci | jwt-dev | jwt-prod
     jwt_algorithm: str  # ES256
     jwt_audience: str  # DatadeftDev | DepoxyProd | HexaLoc | Etc.
     jwt_secret_id: str  # SecretsManager secret id for Signing key
     s3_bucket: str
-    ses_sender_address: str
+    ses_email_subject: str
+    ses_from_email: EmailStr
     stage: str
+    allowed_email_domains: List[str]  # Email domains from which a user log in
 
 
-class Clients:
+class AuthClients:
+
+    s3_client: S3Client = None
+    s3_resource: S3ServiceResource = None
+    sqs_client: SQSClient = None
+    secretsmanager_client: SecretsManagerClient = None
+    glue_client: GlueClient = None
+    ses_client: SESClient = None
+    athena_client: AthenaClient = None
+
     def __init__(
         self,
         s3_client: S3Client,
@@ -42,13 +53,13 @@ class Clients:
         ses_client: SESClient,
         athena_client: AthenaClient,
     ):
-        self.s3_client = s3_client
-        self.s3_resource = s3_resource
-        self.sqs_client = sqs_client
-        self.secretsmanager_client = secretsmanager_client
-        self.glue_client = glue_client
-        self.ses_client = ses_client
-        self.athena_client = athena_client
+        self.s3_client: S3Client = s3_client
+        self.s3_resource: S3ServiceResource = s3_resource
+        self.sqs_client: SQSClient = sqs_client
+        self.secretsmanager_client: SecretsManagerClient = secretsmanager_client
+        self.glue_client: GlueClient = glue_client
+        self.ses_client: SESClient = ses_client
+        self.athena_client: AthenaClient = athena_client
 
 
 class CustomError(BaseModel):
