@@ -513,26 +513,25 @@ class Auth:
         return http_response
 
     def verify_email_domain(self, email_address: EmailStr) -> Union[bool, CustomError]:
+        error_msg = (
+            f"Email domain is not allowed for the email address: {email_address}"
+        )
         try:
             email_domain = email_address.split("@")[-1]
             allowed_email_domains = self.config.allowed_email_domains
             if email_domain in allowed_email_domains:
                 return True
             else:
-                LOG.error(
-                    f"Email domain is not allowed for the email address: {email_address}"
-                )
+                LOG.error(error_msg)
                 return CustomError(
-                    f"Email domain is not allowed for the email address: {email_address}",
-                    [f"{ex}"],
+                    message=error_msg,
+                    reasons=[f"{ex}"],
                 )
         except Exception as ex:
-            LOG.error(
-                f"Email domain is not allowed for the email address: {email_address}"
-            )
+            LOG.error(error_msg)
             return CustomError(
-                f"Email domain is not allowed for the email address: {email_address}",
-                [f"{ex}"],
+                message=error_msg,
+                reasons=[f"{ex}"],
             )
 
     # @router.post("/login", response_model=HttpSuccess)
